@@ -7,15 +7,14 @@ OPENSSL=${OPENSSL-openssl}
 SSLDIR=${SSLDIR-/etc/ssl}
 OPENSSLCONFIG=${OPENSSLCONFIG-${SSLDIR}/dovecot-openssl.cnf}
 
+KEYDIR=$SSLDIR/private
+
 CERTFILE=$SSLDIR/dovecotcert.pem
-KEYFILE=$SSLDIR/private/dovecot.pem
+KEYFILE=$KEYDIR/dovecot.pem
 
-#if [ ! -d $SSLDIR/certs ]; then
-#  echo "$SSLDIR/certs directory doesn't exist"
-#fi
-
-if [ ! -d $SSLDIR/private ]; then
+if [ ! -d $KEYDIR ]; then
   echo "$SSLDIR/private directory doesn't exist"
+  exit 1
 fi
 
 if [ -f $CERTFILE ]; then
@@ -28,7 +27,7 @@ if [ -f $KEYFILE ]; then
   exit 1
 fi
 
-$OPENSSL req -new -x509 -nodes -config $OPENSSLCONFIG -out $CERTFILE -keyout $KEYFILE -days 365 || exit 2
+$OPENSSL req -new -x509 -nodes -config $OPENSSLCONFIG -out $CERTFILE -keyout $KEYFILE -days 730 || exit 2
 chmod 0600 $KEYFILE
 echo 
 $OPENSSL x509 -subject -fingerprint -noout -in $CERTFILE || exit 2
