@@ -1,6 +1,8 @@
 #ifndef DB_PASSWD_FILE_H
 #define DB_PASSWD_FILE_H
 
+#include "hash.h"
+
 #define PASSWD_FILE_DEFAULT_USERNAME_FORMAT "%u"
 #define PASSWD_FILE_DEFAULT_SCHEME "CRYPT"
 
@@ -18,12 +20,13 @@ struct passwd_file {
 	pool_t pool;
 	int refcount;
 
+	time_t last_sync_time;
 	char *path;
 	time_t stamp;
 	off_t size;
 	int fd;
 
-	struct hash_table *users;
+	HASH_TABLE(char *, struct passwd_user *) users;
 };
 
 struct db_passwd_file {
@@ -32,7 +35,7 @@ struct db_passwd_file {
 	int refcount;
 
 	char *path;
-	struct hash_table *files;
+	HASH_TABLE(char *, struct passwd_file *) files;
         struct passwd_file *default_file;
 
 	unsigned int vars:1;
