@@ -8,9 +8,8 @@ struct dotlock_settings;
 
 /* Synchronization can take a while sometimes, especially when copying lots of
    mails. */
-#define MAIL_TRANSCATION_LOG_LOCK_TIMEOUT (3*60)
-#define MAIL_TRANSCATION_LOG_LOCK_CHANGE_TIMEOUT (3*60)
-#define MAIL_TRANSACTION_LOG_LOCK_WARN_SECS 30
+#define MAIL_TRANSACTION_LOG_LOCK_TIMEOUT (3*60)
+#define MAIL_TRANSACTION_LOG_LOCK_CHANGE_TIMEOUT (3*60)
 
 /* Rotate when log is older than ROTATE_TIME and larger than MIN_SIZE */
 #define MAIL_TRANSACTION_LOG_ROTATE_MIN_SIZE (1024*32)
@@ -137,8 +136,10 @@ void mail_transaction_logs_clean(struct mail_transaction_log *log);
 
 bool mail_transaction_log_want_rotate(struct mail_transaction_log *log);
 int mail_transaction_log_rotate(struct mail_transaction_log *log, bool reset);
-int mail_transaction_log_lock_head(struct mail_transaction_log *log);
-void mail_transaction_log_file_unlock(struct mail_transaction_log_file *file);
+int mail_transaction_log_lock_head(struct mail_transaction_log *log,
+				   const char *lock_reason);
+void mail_transaction_log_file_unlock(struct mail_transaction_log_file *file,
+				      const char *lock_reason);
 
 void mail_transaction_update_modseq(const struct mail_transaction_header *hdr,
 				    const void *data, uint64_t *cur_modseq);
