@@ -76,6 +76,8 @@ struct sql_db_vfuncs {
 
 	void (*update)(struct sql_transaction_context *ctx, const char *query,
 		       unsigned int *affected_rows);
+	const char *(*escape_blob)(struct sql_db *db,
+				   const unsigned char *data, size_t size);
 };
 
 struct sql_db {
@@ -83,7 +85,7 @@ struct sql_db {
 	enum sql_db_flags flags;
 
 	struct sql_db_vfuncs v;
-	ARRAY_DEFINE(module_contexts, union sql_db_module_context *);
+	ARRAY(union sql_db_module_context *) module_contexts;
 
 	void (*state_change_callback)(struct sql_db *db,
 				      enum sql_db_state prev_state,
